function doall=OU_DEq
clear;

% Solve Ornstein_Uhlenbeck problem numerically.

% time step: needs to be small enough for a given problem:
delta_t=1;
% Print (and save) every nprint steps:
nprint=1;
% Integration time:
T=100.0;

% Number of steps:
N=floor(T/delta_t);
NP=floor(N/nprint);

% Number of samples:
samples = 1;
finalX = zeros(1,samples);

% Initial conditions:
x=zeros(2,NP, samples);
n=1;
x(:,n)=[0,0]'; 

for s=1:samples
%x(:,n, s)=[rand(1) - 0.5,0]';
x(:,n, s)=[0,0]';
    % Integrate:
    for n=1:1:NP
        xp=x(:,n, s);
        for j=1:1:nprint
             xp=xp+rhs(xp)*delta_t;
        end
        x(:,n+1, s)=xp;
    end
    finalX(s) = x(1,NP, s); 
end

% Plot sample time series:
figure(1)
plot(x(2,:,1),x(1,:,1))
hold on
for s=1:samples
    plot(x(2,:,s),x(1,:,s))
end
hold off
xlabel('time')
ylabel('x')

range = 0.05;
figure(2)
    binWidth = 0.01;
    y = -range:binWidth:range;
%    histogram = hist(finalX);
%    bar(histogram/samples)
    histogram = histc(finalX, y);
    bar(y, histogram/samples)
    title('Final state probability')       
    xlabel('state')
    ylabel('probability')
    ylim([0 0.5])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ff=rhs(x)
% return the rhs of the dynamical system:
noise = 0.01;
ff=[-0.2*x(1)+noise*randn(1),1]';
