function doall=OU_DEq
clear all;

% Solve Ornstein_Uhlenbeck problem numerically using the "modified Euler scheme"
% (a second order, constant step scheme), see Strogatz page 33.

% time step: needs to be small enough for a given problem:
delta_t=0.01;
% Print (and save) every nprint steps:
nprint=1;
% Integration time:
T=150.0;

% Number of steps:
N=floor(T/delta_t);
NP=floor(N/nprint);

% Initial conditions:
x=zeros(3,NP);
n=1;
x(:,n)=[1,0,0]';
%x(:,n)=[rand(1) - 0.5,0,0]';

% Integrate:
for n=1:1:NP
    xp=x(:,n);
    for j=1:1:nprint
         x_tilde=xp+delta_t*rhs(xp);
         xp=xp+0.5*(rhs(xp) + rhs(x_tilde))*delta_t;
    end
    x(:,n+1)=xp;
end

% Plot simple time series:
plot(x(3,:),x(1,:))
xlabel('time')
ylabel('x')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ff=rhs(x)
% return the rhs of the dynamical system:
noise = 1.1;
ff=[-x(1)/10+noise*randn(1),0,1]';
