function doall=OU_DEq
clear;

% Solve Ornstein_Uhlenbeck problem numerically.

% time step: needs to be small enough for a given problem:
delta_t=1;
% Print (and save) every nprint steps:
nprint=1;
% Integration time:
%T=1000.0;
T=100.0;

% Number of steps:
N=floor(T/delta_t);
NP=floor(N/nprint);

% Number of samples:
samples = 20;
finalX = zeros(1,samples);

% Initial conditions:
x=zeros(2,NP, samples);
n=1;
x(:,n)=[1,0]'; 

for s=1:samples
x(:,n, s)=[rand(1) - 0.5,0]';
    % Integrate:
    for n=1:1:NP
        xp=x(:,n, s);
        for j=1:1:nprint
             xp=xp+rhs(xp)*delta_t;
        end
        x(:,n+1, s)=xp;
    end
    finalX(s) = x(1,NP, s); 
end


% Plot sample time series:
figure(1)
plot(x(2,:,2),x(1,:,2))
% hold on
% for s=1:samples
%     plot(x(2,:,s),x(1,:,s))
% end
% hold off
xlabel('time')
ylabel('x')

range = 4;
figure(2)
    binWidth = 0.05;
    y = -range:binWidth:range;
    histogram = histc(finalX, y);
    bar(y, histogram/samples)
    title('Final state probability')       
    xlabel('state')
    ylabel('probability')
    ylim([0 0.5])

%  figure(2)
%     Y = fft(x(1,:, s),512);
%     Pyy = Y.* conj(Y) / 512;
%     f = 1000*(0:256)/512;
%     plot(f,Pyy(1:257))
%     title('Frequency content')
%     xlabel('frequency (cycles/sample)')
%     ylim([0 50])
%     xlim([0 200])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ff=rhs(x)
% return the rhs of the dynamical system:
noise = 1.5;
%ff=[0.5*x(1)-0.04*x(1)^3+0.+noise*randn(1),1]';
ff=[0.5*x(1)-0.04*x(1)^3+0.5*sin(15*pi*x(2)/100)+noise*randn(1),1]';
