% Ornstein-Uhlenbeck Process - Random Walk

clear
N = 30;                                 % number of states (N is odd)
max_steps = 100;                        % maximum number of steps
max_walks = 1000;                          % maximum number of steps
e_0 = round((N+1)/2);                   % set initial-state vector
states = zeros(max_walks,max_steps);    % initialize state matrix
stateProb = zeros(N,max_steps);         % initialize state matrix
for w=1:max_walks
    e_n = e_0;                          % present state = initial-state
    states(w,1) = e_n;
    stateProb(e_n,1) =  1; 
    % --- Loop through walk -------
    for n=2:max_steps
        p = 0.5 - (e_n - e_0)/(2*e_0);                        % up-step probability
        q = 1-p;                        % down-step probability
        randomNum = rand(1);
        if randomNum<p
            e_n = e_n+1;
        else
            e_n = e_n-1;
        end
        if e_n>N
            e_n = 1;
        end
        if e_n<1
            e_n = N;
        end
        states(w,n) = e_n;
        stateProb(e_n,n) = stateProb(e_n,n) + 1; 
    end
end
figure(1)
    imagesc (stateProb/max_walks);
    colorbar;
    title('Random Walk Probabilities')       
    xlabel('steps')
    ylabel('state')

finalProb = (stateProb(:,max_steps) + stateProb(:,max_steps-1))/max_walks;
figure(2)
    plot (finalProb);
    title('Final state probability')       
    xlabel('state')
    ylabel('probability')
    ylim([0 0.5])
    
% figure(3)
%     plot (states');
%     ylim([-1 N])
%     title('Random Walks')       
%     xlabel('steps')
%     ylabel('state')

